# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class AvailabilityZoneGroup(pulumi.CustomResource):
    group_name: pulumi.Output[str]
    """
    Name of the Availability Zone Group.
    """
    opt_in_status: pulumi.Output[str]
    """
    Indicates whether to enable or disable Availability Zone Group. Valid values: `opted-in` or `not-opted-in`.
    """
    def __init__(__self__, resource_name, opts=None, group_name=None, opt_in_status=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages an EC2 Availability Zone Group, such as updating its opt-in status.

        > **NOTE:** This is an advanced resource. The provider will automatically assume management of the EC2 Availability Zone Group without import and perform no actions on removal from configuration.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.ec2.AvailabilityZoneGroup("example",
            group_name="us-west-2-lax-1",
            opt_in_status="opted-in")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] group_name: Name of the Availability Zone Group.
        :param pulumi.Input[str] opt_in_status: Indicates whether to enable or disable Availability Zone Group. Valid values: `opted-in` or `not-opted-in`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if group_name is None:
                raise TypeError("Missing required property 'group_name'")
            __props__['group_name'] = group_name
            if opt_in_status is None:
                raise TypeError("Missing required property 'opt_in_status'")
            __props__['opt_in_status'] = opt_in_status
        super(AvailabilityZoneGroup, __self__).__init__(
            'aws:ec2/availabilityZoneGroup:AvailabilityZoneGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, group_name=None, opt_in_status=None):
        """
        Get an existing AvailabilityZoneGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] group_name: Name of the Availability Zone Group.
        :param pulumi.Input[str] opt_in_status: Indicates whether to enable or disable Availability Zone Group. Valid values: `opted-in` or `not-opted-in`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["group_name"] = group_name
        __props__["opt_in_status"] = opt_in_status
        return AvailabilityZoneGroup(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

